/* _dict.cc 14/11/1998 19.13.02 */
/* ppp.cc 24/11/2000 00.01.46 */
PUBLIC RHPPP::RHPPP (const char *dev);
PUBLIC void RHPPP::setdevice (const char *dev);
PRIVATE void RHPPP::init (void);
PUBLIC RHPPP::RHPPP (void);
PRIVATE void RHPPP::addspcaborts (void);
PRIVATE void RHPPP::delspcaborts (void);
PUBLIC int RHPPP::load (void);
PRIVATE void RHPPP::settitle (char title[100]);
PRIVATE void RHPPP::setmodemfield (DIALOG&dia);
PUBLIC int RHPPP::edit (void);
PUBLIC int RHPPP::editnew (void);
PUBLIC int RHPPP::write (void);
PUBLIC CONFIG_FILE_PTPLIST::CONFIG_FILE_PTPLIST (void);
PUBLIC int CONFIG_FILE_PTPLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_PTPLIST::extract (SSTREAM&ss);
/* redhatppp.cc 24/11/2000 00.01.46 */
PUBLIC MODULE_redhatppp::MODULE_redhatppp (void);
PUBLIC void MODULE_redhatppp::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_redhatppp::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_redhatppp::dohtml (const char *key);
PUBLIC int MODULE_redhatppp::execmain (int argc, char *argv[], bool);
/* wvdial.cc 24/11/2000 00.01.46 */
